unit AddChange;

interface

uses
  Windows, SysUtils, Classes, Graphics, Forms, Controls, StdCtrls,
  Buttons, ExtCtrls;
       
type
  TAddChangeAction = (acAdd, acDelete);
  TAddChangeActions = set of TAddChangeAction;

  TAddChangeForm = class(TForm)
    OKBtn: TButton;
    CancelBtn: TButton;
    Bevel1: TBevel;
    lblCommand: TLabel;
    edtCommand: TEdit;
    chkPeriodically: TCheckBox;
    lbxDays: TListBox;
    lblDays: TLabel;
    lblTime: TLabel;
    edtHours: TEdit;
    edtMinutes: TEdit;
    lblColon: TLabel;
    chkInteractive: TCheckBox;
    procedure FormCreate(Sender: TObject);
    procedure OKBtnClick(Sender: TObject);
  private
    { Private declarations }
    FAddChange  : TAddChangeActions;
    FJobId      : LongWord;
    FServername : String;
    procedure FillListbox;
    procedure JobAdd;
  public
    { Public declarations }
    procedure JobShow;
  published
    property AddChange : TAddChangeActions read FAddChange write FAddChange;
    property JobId : LongWord read FJobId write FJobId;
    property Servername : String read FServername write FServername;
  end;


var
  AddChangeForm: TAddChangeForm;

implementation

uses
  LMat, NetScheduleJob;

{$R *.DFM}

//------------------------------------------------------------------------------
procedure TAddChangeForm.FillListbox;
var
  i : Integer;
begin
  lbxDays.Clear;

  // days of week
  for i := 1 to 7 do
    lbxDays.Items.Add(LongDayNames[i]);

  // days of month
  for i := 1 to 31 do
    lbxDays.Items.Add(IntToStr(I));
end;

//------------------------------------------------------------------------------
procedure TAddChangeForm.FormCreate(Sender: TObject);
begin
  FillListbox;
  AddChange := [] + [acAdd];
end;

//------------------------------------------------------------------------------
procedure TAddChangeForm.JobAdd;
var
  AtInfo : AT_INFO;
  Cmd    : TServername;
  Dest   : TServerName;
  i, j   : Integer;
begin
  with AtInfo do
  begin
    JobTime := StringToJobTime(edtHours.Text, edtMinutes.Text);

    DaysOfMonth := 0;
    DaysOfWeek  := 0;
    for i := 0 to lbxDays.Items.Count-1 do
    begin
      if lbxDays.Selected[i] then
      begin
        if (i >= 7) then
          DaysOfMonth := DaysOfMonth or (1 shl (i-7))
        else
        begin
          if i = 0 then
            j := 7
          else
            j := i;
          DaysOfWeek  := DaysOfWeek or (1 shl (j-1));
        end;
      end;
    end;

    Flags := 0;
    if chkPeriodically.Checked then
      Flags := Flags + JOB_RUN_PERIODICALLY;

    if not chkInteractive.Checked then
      Flags := Flags + JOB_NONINTERACTIVE;

    Command := StringToWideChar(edtCommand.Text, @Cmd, SizeOf(Dest) div 2);
  end;

  StringToWideChar(Servername, @Dest, SizeOf(Dest) div 2);
  NetScheduleJobAdd(Dest, PByte(@AtInfo), @FJobId);
end;

//------------------------------------------------------------------------------
procedure TAddChangeForm.JobShow;
var
  Dest    : TServerName;
  i       : Integer;
  pAtInfo : PAT_INFO;
  TempStr : String;
begin
  StringToWideChar(Servername, @Dest, SizeOf(Dest) div 2);
  NetScheduleJobGetInfo(Dest, JobId, PByte(@pAtInfo));

  AddChange               := [] + [acAdd, acDelete];
  edtCommand.Text         := pAtInfo^.Command;
  chkPeriodically.Checked := RunPeriodically(pAtInfo^.Flags);
  chkInteractive.Checked  := RunInteractive(pAtInfo^.Flags);
  TempStr                 := JobTimeToStr(pAtInfo^.JobTime);
  edtHours.Text           := Copy(TempStr, 1, 2);
  edtMinutes.Text         := Copy(TempStr, 4, 2);

  if (pAtInfo^.DaysOfWeek <> 0) then
    for i := 0 to 7 do
      if (pAtInfo^.DaysOfWeek and (1 shl i) <> 0 ) then
      begin
        if (i < 6) then
          lbxDays.Selected[i+1] := True
        else
          lbxDays.Selected[0] := True;
      end;

  if (pAtInfo^.DaysOfMonth <> 0) then
    for i := 0 to 31 do
      if (pAtInfo^.DaysOfMonth and (1 shl i) <> 0) then
        lbxDays.Selected[7+i] := True;
end;

//------------------------------------------------------------------------------
procedure TAddChangeForm.OKBtnClick(Sender: TObject);
var
  Dest : TServername;
begin
  if (acDelete in AddChange) then
  begin
    StringToWideChar(Servername, @Dest, SizeOf(Dest) div 2);
    NetScheduleJobDel(Dest, FJobId, FJobId);
  end;

  if (acAdd in AddChange) then
    JobAdd;
end;

end.
